# Changelog

## 0.1.0-alpha.10 (2024-10-16)

Full Changelog: [v0.1.0-alpha.9...v0.1.0-alpha.10](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.9...v0.1.0-alpha.10)

### Features

* **api:** api update ([#88](https://github.com/conductor-is/conductor-python/issues/88)) ([47528b8](https://github.com/conductor-is/conductor-python/commit/47528b8f9adc1bbcc9fa8546e706773bde3e53da))
* **api:** api update ([#90](https://github.com/conductor-is/conductor-python/issues/90)) ([041768f](https://github.com/conductor-is/conductor-python/commit/041768ffbfa1c651672714522c3f1fc9b3b41acd))

## 0.1.0-alpha.9 (2024-10-15)

Full Changelog: [v0.1.0-alpha.8...v0.1.0-alpha.9](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.8...v0.1.0-alpha.9)

### Features

* **api:** api update ([#85](https://github.com/conductor-is/conductor-python/issues/85)) ([25aadd4](https://github.com/conductor-is/conductor-python/commit/25aadd46efa964e8e67af36944117c948f4537da))

## 0.1.0-alpha.8 (2024-10-15)

Full Changelog: [v0.1.0-alpha.7...v0.1.0-alpha.8](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.7...v0.1.0-alpha.8)

### Features

* **api:** api update ([#74](https://github.com/conductor-is/conductor-python/issues/74)) ([d78d12d](https://github.com/conductor-is/conductor-python/commit/d78d12dd6e67e81ac9aeda72d19872e75d97f4ee))
* **api:** api update ([#76](https://github.com/conductor-is/conductor-python/issues/76)) ([d9707ac](https://github.com/conductor-is/conductor-python/commit/d9707ac5b91294665635024d522607cf5c292473))
* **api:** api update ([#77](https://github.com/conductor-is/conductor-python/issues/77)) ([ce621f4](https://github.com/conductor-is/conductor-python/commit/ce621f49a6359146915c4b6708b8ebee93dde0ac))
* **api:** api update ([#78](https://github.com/conductor-is/conductor-python/issues/78)) ([9bbbefc](https://github.com/conductor-is/conductor-python/commit/9bbbefcdef97e8cae0da28ca4e22d08d847e63b4))
* **api:** api update ([#79](https://github.com/conductor-is/conductor-python/issues/79)) ([2531f9a](https://github.com/conductor-is/conductor-python/commit/2531f9a7feb82f64061f1b936222905113af7568))
* **api:** api update ([#80](https://github.com/conductor-is/conductor-python/issues/80)) ([4d9bcd4](https://github.com/conductor-is/conductor-python/commit/4d9bcd4919853a43bc7eb79637597d885f918819))
* **api:** api update ([#81](https://github.com/conductor-is/conductor-python/issues/81)) ([b68a9f0](https://github.com/conductor-is/conductor-python/commit/b68a9f0dacdb62f66eb272a1de09e0073afafa34))
* **api:** api update ([#82](https://github.com/conductor-is/conductor-python/issues/82)) ([3088198](https://github.com/conductor-is/conductor-python/commit/308819821a26c5a1af87d7a096098b4adc56a72a))
* **api:** api update ([#83](https://github.com/conductor-is/conductor-python/issues/83)) ([5e412c9](https://github.com/conductor-is/conductor-python/commit/5e412c9ba388aca61a2cfa8b2709d75779664d94))

## 0.1.0-alpha.7 (2024-10-13)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **api:** api update ([#64](https://github.com/conductor-is/conductor-python/issues/64)) ([be0d706](https://github.com/conductor-is/conductor-python/commit/be0d7065ee51175487b8005e62d9d06f7a5ecbfc))
* **api:** api update ([#66](https://github.com/conductor-is/conductor-python/issues/66)) ([13c840a](https://github.com/conductor-is/conductor-python/commit/13c840a629c0d7a50456ecf47b274153f4faa0ab))
* **api:** api update ([#67](https://github.com/conductor-is/conductor-python/issues/67)) ([54e5574](https://github.com/conductor-is/conductor-python/commit/54e5574c0c878db84febda4bf57093cf61fccb7f))
* **api:** api update ([#68](https://github.com/conductor-is/conductor-python/issues/68)) ([d6b7732](https://github.com/conductor-is/conductor-python/commit/d6b77326ffe72049bf4ca9e79d137bf7d5236fee))
* **api:** api update ([#69](https://github.com/conductor-is/conductor-python/issues/69)) ([6f92519](https://github.com/conductor-is/conductor-python/commit/6f92519a728c9630178ed641881738afce8e91ae))
* **api:** api update ([#70](https://github.com/conductor-is/conductor-python/issues/70)) ([157b28a](https://github.com/conductor-is/conductor-python/commit/157b28a93fb9e3c540f2fc68adab6b7bba34b975))

## 0.1.0-alpha.6 (2024-10-11)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** api update ([#54](https://github.com/conductor-is/conductor-python/issues/54)) ([eb97202](https://github.com/conductor-is/conductor-python/commit/eb97202f7585b7285531c59684d27bede40ef65a))
* **api:** api update ([#55](https://github.com/conductor-is/conductor-python/issues/55)) ([a11a233](https://github.com/conductor-is/conductor-python/commit/a11a23325b622b55bba42da190dca9fb1abd3c01))
* **api:** api update ([#56](https://github.com/conductor-is/conductor-python/issues/56)) ([d75fe5c](https://github.com/conductor-is/conductor-python/commit/d75fe5c0182c74e31e8caf66ecf4272a0d0855a8))
* **api:** api update ([#57](https://github.com/conductor-is/conductor-python/issues/57)) ([028221b](https://github.com/conductor-is/conductor-python/commit/028221bd3fafe30ac1748211f25ad041143d43b7))
* **api:** api update ([#58](https://github.com/conductor-is/conductor-python/issues/58)) ([3da87a3](https://github.com/conductor-is/conductor-python/commit/3da87a3896b069ba2b9caa91aed12ca7ca0becec))
* **api:** api update ([#59](https://github.com/conductor-is/conductor-python/issues/59)) ([72e66d8](https://github.com/conductor-is/conductor-python/commit/72e66d86398016171d5db70faf4d3c00eb19a029))
* **api:** api update ([#60](https://github.com/conductor-is/conductor-python/issues/60)) ([9e1cfc5](https://github.com/conductor-is/conductor-python/commit/9e1cfc5883d1f5bb39ffa296589e3ffc8f60ca91))
* **api:** api update ([#61](https://github.com/conductor-is/conductor-python/issues/61)) ([b8500c9](https://github.com/conductor-is/conductor-python/commit/b8500c9a5f47d7d24506bf5298e6ef5888e2501a))
* **api:** manual updates ([#48](https://github.com/conductor-is/conductor-python/issues/48)) ([937a294](https://github.com/conductor-is/conductor-python/commit/937a29406616ac3b157a40cf57afb5b2fa2d4eb1))
* **api:** OpenAPI spec update via Stainless API ([#44](https://github.com/conductor-is/conductor-python/issues/44)) ([833e15c](https://github.com/conductor-is/conductor-python/commit/833e15cc216753635a4b9b675a55933207605952))
* **api:** OpenAPI spec update via Stainless API ([#49](https://github.com/conductor-is/conductor-python/issues/49)) ([1acf56d](https://github.com/conductor-is/conductor-python/commit/1acf56d3d3d6227597c42d4aca3880149c0801a6))
* **api:** OpenAPI spec update via Stainless API ([#50](https://github.com/conductor-is/conductor-python/issues/50)) ([95b0cf7](https://github.com/conductor-is/conductor-python/commit/95b0cf7a5c82de9fecb8f602b0fe14a988c817a2))
* **api:** OpenAPI spec update via Stainless API ([#51](https://github.com/conductor-is/conductor-python/issues/51)) ([45d59e1](https://github.com/conductor-is/conductor-python/commit/45d59e15a9e26e6f3beacf901e539825944d306f))
* **api:** OpenAPI spec update via Stainless API ([#52](https://github.com/conductor-is/conductor-python/issues/52)) ([d8b2520](https://github.com/conductor-is/conductor-python/commit/d8b2520898dcc42d284545cacb9fef304aa8b47f))
* **api:** OpenAPI spec update via Stainless API ([#53](https://github.com/conductor-is/conductor-python/issues/53)) ([8d18a81](https://github.com/conductor-is/conductor-python/commit/8d18a81da2d72c8320cf250aa6d90d9868757a5e))


### Bug Fixes

* **client:** avoid OverflowError with very large retry counts ([#46](https://github.com/conductor-is/conductor-python/issues/46)) ([169b02c](https://github.com/conductor-is/conductor-python/commit/169b02cab2670283bcb4fdca71f97273e25dde82))


### Chores

* add repr to PageInfo class ([#47](https://github.com/conductor-is/conductor-python/issues/47)) ([de0c019](https://github.com/conductor-is/conductor-python/commit/de0c0191d7c082bef2050a5225bd325b46233068))

## 0.1.0-alpha.5 (2024-10-06)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** update via SDK Studio ([#38](https://github.com/conductor-is/conductor-python/issues/38)) ([2ea197b](https://github.com/conductor-is/conductor-python/commit/2ea197ba93ee128b07697900af32d1eadd959fc9))


### Chores

* **internal:** add support for parsing bool response content ([#42](https://github.com/conductor-is/conductor-python/issues/42)) ([b59e831](https://github.com/conductor-is/conductor-python/commit/b59e831d1a32f4f23f392ec634f2154fba1c06b5))
* **internal:** codegen related update ([#40](https://github.com/conductor-is/conductor-python/issues/40)) ([f759a7a](https://github.com/conductor-is/conductor-python/commit/f759a7a89512509169e0f8ded4bd7d2ce3e2d147))
* **internal:** codegen related update ([#41](https://github.com/conductor-is/conductor-python/issues/41)) ([3e863ee](https://github.com/conductor-is/conductor-python/commit/3e863ee5cf5418a95ab884b17d5bc1cb511b6aa0))

## 0.1.0-alpha.4 (2024-09-30)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** update via SDK Studio ([#27](https://github.com/conductor-is/conductor-python/issues/27)) ([889eca4](https://github.com/conductor-is/conductor-python/commit/889eca4a6fc284f5ef954a972e88cd8640b82b22))
* **api:** update via SDK Studio ([#29](https://github.com/conductor-is/conductor-python/issues/29)) ([1b59254](https://github.com/conductor-is/conductor-python/commit/1b592549e266594ca0abb7bcdb104be7f1cd7ebb))
* **api:** update via SDK Studio ([#30](https://github.com/conductor-is/conductor-python/issues/30)) ([fa7c51a](https://github.com/conductor-is/conductor-python/commit/fa7c51ad61d34a2fe9e26925a1d7cf26990d41df))
* **api:** update via SDK Studio ([#33](https://github.com/conductor-is/conductor-python/issues/33)) ([7f0f5ee](https://github.com/conductor-is/conductor-python/commit/7f0f5ee693cb0c0a90b652e8ed9a8e1228f147df))
* **client:** send retry count header ([#32](https://github.com/conductor-is/conductor-python/issues/32)) ([10faf81](https://github.com/conductor-is/conductor-python/commit/10faf813124c37b08113d7de41f3920bd1886a0c))


### Bug Fixes

* **client:** handle domains with underscores ([#31](https://github.com/conductor-is/conductor-python/issues/31)) ([8e750e1](https://github.com/conductor-is/conductor-python/commit/8e750e1a6799fea10221d09e7fc38fb2bfe9163f))


### Chores

* **internal:** codegen related update ([#35](https://github.com/conductor-is/conductor-python/issues/35)) ([52c3970](https://github.com/conductor-is/conductor-python/commit/52c3970e956893a39e7bba9399538b7646901aca))
* **internal:** codegen related update ([#36](https://github.com/conductor-is/conductor-python/issues/36)) ([31d4ef4](https://github.com/conductor-is/conductor-python/commit/31d4ef47f4da3f0f508d8f50a1b164ea1ce194d2))
* **internal:** update pydantic v1 compat helpers ([#34](https://github.com/conductor-is/conductor-python/issues/34)) ([68fffdb](https://github.com/conductor-is/conductor-python/commit/68fffdb97d5f765d59df9588fcb1577fd569f608))

## 0.1.0-alpha.3 (2024-09-18)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** update via SDK Studio ([#16](https://github.com/conductor-is/conductor-python/issues/16)) ([db50bae](https://github.com/conductor-is/conductor-python/commit/db50bae0dcd000a0a4697a8042327ad9ad7f05b4))
* **api:** update via SDK Studio ([#18](https://github.com/conductor-is/conductor-python/issues/18)) ([b18af59](https://github.com/conductor-is/conductor-python/commit/b18af595f682ccf653f82d3cba776b57171547e1))
* **api:** update via SDK Studio ([#19](https://github.com/conductor-is/conductor-python/issues/19)) ([83aeedd](https://github.com/conductor-is/conductor-python/commit/83aeedd330ff2a890322e32b64a98862d6df0c9b))
* **api:** update via SDK Studio ([#22](https://github.com/conductor-is/conductor-python/issues/22)) ([d820537](https://github.com/conductor-is/conductor-python/commit/d82053740ad57792048b477ee3b92dc78e1e7fc3))
* **api:** update via SDK Studio ([#23](https://github.com/conductor-is/conductor-python/issues/23)) ([26f5d61](https://github.com/conductor-is/conductor-python/commit/26f5d61f657cddc5bb1d9ae386d7477872e73f32))
* **api:** update via SDK Studio ([#24](https://github.com/conductor-is/conductor-python/issues/24)) ([820c8c3](https://github.com/conductor-is/conductor-python/commit/820c8c384286e3a7c79a40832a0426f7eb7302c4))
* **api:** update via SDK Studio ([#25](https://github.com/conductor-is/conductor-python/issues/25)) ([d1fc04b](https://github.com/conductor-is/conductor-python/commit/d1fc04b036c23c03316cf91cdc4d897959458ca9))


### Chores

* add docstrings to raw response properties ([#13](https://github.com/conductor-is/conductor-python/issues/13)) ([6300c96](https://github.com/conductor-is/conductor-python/commit/6300c9613a7a056cc2ad21a401730a148a59da4a))
* **internal:** bump pyright / mypy version ([#21](https://github.com/conductor-is/conductor-python/issues/21)) ([a6e8897](https://github.com/conductor-is/conductor-python/commit/a6e8897535da4f3a396badb4c3fe34455c32beb6))
* **internal:** bump ruff ([#20](https://github.com/conductor-is/conductor-python/issues/20)) ([9e245df](https://github.com/conductor-is/conductor-python/commit/9e245df647a688ede26f8d79e3c42612cd5a8766))


### Documentation

* **readme:** add section on determining installed version ([#14](https://github.com/conductor-is/conductor-python/issues/14)) ([b7c9f8b](https://github.com/conductor-is/conductor-python/commit/b7c9f8bb1f96d2c256a229fd3321f4ce7def744e))
* update CONTRIBUTING.md ([#17](https://github.com/conductor-is/conductor-python/issues/17)) ([96cb918](https://github.com/conductor-is/conductor-python/commit/96cb918d7393283736cd6e29b8b0b034cd81aece))

## 0.1.0-alpha.2 (2024-09-08)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([#11](https://github.com/conductor-is/conductor-python/issues/11)) ([fb69258](https://github.com/conductor-is/conductor-python/commit/fb69258a1df4e3cee8fa6ebe056b0336724b2c1f))
* **api:** update via SDK Studio ([#7](https://github.com/conductor-is/conductor-python/issues/7)) ([6708001](https://github.com/conductor-is/conductor-python/commit/670800117c6222c8ee30f85f2c90f7e114b73302))


### Chores

* pyproject.toml formatting changes ([#9](https://github.com/conductor-is/conductor-python/issues/9)) ([ceac058](https://github.com/conductor-is/conductor-python/commit/ceac0582eb3ebb352bbf9ce26e930d40eb9b39f6))

## 0.1.0-alpha.1 (2024-09-02)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/conductor-is/conductor-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([b6472f6](https://github.com/conductor-is/conductor-python/commit/b6472f626e01f0db7d43f7877bf2f5e2ecf5fddb))
* **api:** update via SDK Studio ([#4](https://github.com/conductor-is/conductor-python/issues/4)) ([c211314](https://github.com/conductor-is/conductor-python/commit/c2113146925f252addb52f99a25a0ac0e873597a))
* **api:** update via SDK Studio ([#5](https://github.com/conductor-is/conductor-python/issues/5)) ([253d78c](https://github.com/conductor-is/conductor-python/commit/253d78c50259ec7e1cde2d66a6cfcc137252bc0b))


### Chores

* go live ([#1](https://github.com/conductor-is/conductor-python/issues/1)) ([4be56ce](https://github.com/conductor-is/conductor-python/commit/4be56ce217400f0013c503ccdf82f96b0abe35c4))
* update SDK settings ([#3](https://github.com/conductor-is/conductor-python/issues/3)) ([f042384](https://github.com/conductor-is/conductor-python/commit/f04238468a1f22471e26f5bcd8b3e97a59ca4af9))
